<?php
/**
 * ACF Functions for Fields
 */

/**
 * Public Post types
 *
 * Allow 3rd party plugins to filters the public post types should work on
 *
 *  @param  $args (array) to add addition post types
 *  @return $post_types
 */
function geeks_acf_get_public_post_types( $args = [] ) {
	$post_type_args = [
		// Default is the value $public.
		'show_in_nav_menus' => true,
	];

	// Keep for backwards compatibility
	if ( ! empty( $args['post_type'] ) ) {
		$post_type_args['name'] = $args['post_type'];
		unset( $args['post_type'] );
	}

	$post_type_args = wp_parse_args( $post_type_args, $args );

	$_post_types = get_post_types( $post_type_args, 'objects' );

	$post_types = [];

	foreach ( $_post_types as $post_type => $object ) {
		$post_types[ $post_type ] = $object->label;
	}

	// $post_types[ 'by_id' ] = esc_html__( 'Manual Selection', 'geeks' );.

	return apply_filters( 'geeks_acf_get_public_post_types', $post_types );
}

/**
 *  geeks_acf_get_taxonomies_for_post_types
 *
 *  Returns an array of taxonomies for a given post type(s)
 *
 *  @date    7/9/18
 *  @since   5.7.5
 *
 *  @param   string|array $post_types The post types to compare against.
 *  @return  array
 */
function geeks_acf_get_taxonomies_for_post_types( $post_types = array( 'post' ) ) {

	// vars
	$taxonomies = array();

	// loop
	$object_taxonomies = get_object_taxonomies( $post_types );
	foreach ( (array) $object_taxonomies as $taxonomy ) {
		$taxonomies[] = $taxonomy;
	}

	// remove duplicates
	$taxonomies = array_unique( $taxonomies );

	// return
	return apply_filters( 'geeks_acf_get_taxonomies', $taxonomies );
}

/**
 *  geeks_acf_get_terms_for_taxonomies
 *
 *  Returns an array of terms for a given taxonomy(s)
 *
 *  @date    7/9/18
 *  @since   5.7.5
 *
 *  @param   string|array $taxonomies The taxonomies to compare against.
 *  @return  array
 */
function geeks_acf_get_terms_for_taxonomies( $taxonomies = array() ) {
	global $wp_taxonomies;

	// vars
	$terms = array();

	$object_terms = get_terms(
		array(
			'taxonomy'   => $taxonomies,
			'hide_empty' => false,
		)
	);

	foreach ( (array) $object_terms as $term ) {
		$terms[ $term->slug ] = $wp_taxonomies[ $term->taxonomy ]->labels->name . ': ' . $term->name;
	}

	// remove duplicates
	$terms = array_unique( $terms );

	// return
	return apply_filters( 'geeks_acf_get_terms', $terms );
}

/**
 *  geeks_acf_get_author_users
 *
 *  Returns an array of user who have access to post
 *
 *  @param   array $args to WP_User_Query object.
 *  @return  array
 */
function geeks_acf_get_author_users( $args = [] ) {

	$default_args = [
		'who'                 => 'authors',
		'has_published_posts' => true,
		'fields'              => [
			'ID',
			'user_login',
			'display_name',
		],
		'search_columns'      => [
			'user_login',
			'user_nicename',
		],
	];

	$args = wp_parse_args( $args, $default_args );

	$user_query = new \WP_User_Query( $args );

	$authors_choises = array();
	foreach ( $user_query->get_results() as $author ) {
		$authors_choises[ $author->ID ] = $author->display_name;
	}

	// return
	return apply_filters( 'geeks_acf_get_author_users', $authors_choises );
}
