<?php
/**
 * Geeks Plugin Install Class
 *
 * @package  geeks
 * @since    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Geeks_Plugin_Install' ) ) :
	/**
	 * The Geeks plugin install class
	 */
	class Geeks_Plugin_Install {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_action( 'admin_enqueue_scripts', array( $this, 'plugin_install_scripts' ) );
			add_action( 'tgmpa_register', [ $this, 'register_required_plugins' ] );
		}

		/**
		 * Wrapper around the core WP get_plugins function, making sure it's actually available.
		 *
		 * @since 2.5.0
		 *
		 * @param string $plugin_folder Optional. Relative path to single plugin folder.
		 * @return array Array of installed plugins with plugin information.
		 */
		public function get_plugins( $plugin_folder = '' ) {
			if ( ! function_exists( 'get_plugins' ) ) {
				require_once ABSPATH . 'wp-admin/includes/plugin.php';
			}

			return get_plugins( $plugin_folder );
		}

		/**
		 * Helper function to extract the file path of the plugin file from the
		 * plugin slug, if the plugin is installed.
		 *
		 * @since 2.0.0
		 *
		 * @param string $slug Plugin slug (typically folder name) as provided by the developer.
		 * @return string Either file path for plugin if installed, or just the plugin slug.
		 */
		protected function get_plugin_basename_from_slug( $slug ) {
			$keys = array_keys( $this->get_plugins() );

			foreach ( $keys as $key ) {
				if ( preg_match( '|^' . $slug . '/|', $key ) ) {
					return $key;
				}
			}

			return $slug;
		}

		/**
		 * Check if all plugins profile are installed
		 *
		 * @param array $plugins Array of plugin required for a given demo.
		 */
		public function requires_install_plugins( $plugins ) {
			$requires = false;

			foreach ( $plugins as $plugin ) {
				$plugin['file_path']   = $this->get_plugin_basename_from_slug( $plugin['slug'] );
				$plugin['is_callable'] = '';

				if ( ! TGM_Plugin_Activation::is_active( $plugin ) ) {
					$requires = true;
					break;
				}
			}

			return $requires;
		}

		/**
		 * Load plugin install scripts
		 *
		 * @param string $hook_suffix the current page hook suffix.
		 * @return void
		 * @since  1.4.4
		 */
		public function plugin_install_scripts( $hook_suffix ) {
			global $geeks, $geeks_version;

			$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '';

			wp_register_script( 'geeks-plugin-install', get_template_directory_uri() . '/assets/js/admin/plugin-install' . $suffix . '.js', array( 'jquery', 'updates' ), $geeks_version, 'all' );

			$params = [
				'tgmpa_url'   => admin_url( add_query_arg( 'page', 'tgmpa-install-plugins', 'themes.php' ) ),
				'txt_install' => esc_html__( 'Install Plugins', 'geeks' ),
				'profiles'    => $this->get_profile_params(),
			];

			if ( geeks_is_ocdi_activated() ) {
				$params['file_args'] = $geeks->ocdi->import_files();
			}
			wp_localize_script( 'geeks-plugin-install', 'ocdi_params', $params );
			wp_enqueue_script( 'geeks-plugin-install' );

			wp_enqueue_style( 'geeks-plugin-install', get_template_directory_uri() . '/assets/css/admin/plugin-install.css', array(), $geeks_version, 'all' );
		}

		/**
		 * Get Profile params
		 */
		public function get_profile_params() {
			$profiles = $this->get_demo_profiles();
			$params   = [];
			foreach ( $profiles as $key => $profile ) {
				$plugins                            = $this->get_demo_plugins( $key );
				$params[ $key ]['requires_install'] = $this->requires_install_plugins( $plugins );
				if ( $params[ $key ]['requires_install'] ) {
					if( $key !== 'learndash' ) {
						$params['all']['requires_install'] = true;
					} else {
						$params['all']['requires_install'] = false;
					}
					
				}
			}
			return $params;
		}

		/**
		 * Get Demo Profiles
		 */
		public function get_demo_profiles() {
			return array(
				'default' => array(
					array(
						'name'     => 'Elementor',
						'slug'     => 'elementor',
						'required' => true,
					),
					array(
						'name'     => 'Geeks Elementor',
						'slug'     => 'geeks-elementor',
						'source'   => 'http://transvelo.github.io/geeks/assets/plugins/geeks-elementor.zip',
						'required' => true,
					),
					array(
						'name'     => 'Geeks Extensions',
						'slug'     => 'geeks-extensions',
						'source'   => 'http://transvelo.github.io/geeks/assets/plugins/geeks-extensions.zip',
						'required' => true,
					),
					array(
						'name'     => 'One Click Demo Import',
						'slug'     => 'one-click-demo-import',
						'required' => false,
					),
					array(
						'name'     => 'Safe SVG',
						'slug'     => 'safe-svg',
						'required' => false,
					),
					array(
						'name'     => 'Advanced Custom Fields',
						'slug'     => 'advanced-custom-fields',
						'required' => false,
					),
					array(
						'name'     => 'MAS Static Content',
						'slug'     => 'mas-static-content',
						'required' => true,
					),
					array(
						'name'     => 'TablePress',
						'slug'     => 'tablepress',
						'required' => true,
					),
					
				),
				'tutor'       => array(
					array(
						'name'     => 'Tutor',
						'slug'     => 'tutor',
						'required' => true,
					),
				),
				'learndash' => array(
					array(
						'name'     => 'MAS Elementor',
						'slug'     => 'mas-addons-for-elementor',
						'required' => true,
					),

				),
				'shop'       => array(
					array(
						'name'     => 'Tutor',
						'slug'     => 'tutor',
						'required' => true,
					),
					array(
						'name'     => 'Woocommerce',
						'slug'     => 'woocommerce',
						'required' => false,
					),
				),
				'jobs'    => array(
                    array(
						'name'     => 'Tutor',
						'slug'     => 'tutor',
						'required' => true,
					),
					array(
                        'name'     => 'WP Job Manager',
                        'slug'     => 'wp-job-manager',
                        'required' => false
                    ),
                ),
			);
		}

		/**
		 * Get demo Plugins
		 *
		 * @param string $demo slug of the demo for which plugins are request.
		 */
		public function get_demo_plugins( $demo = 'default' ) {
			$profiles = $this->get_demo_profiles();
			$plugins  = [];

			foreach ( $profiles as $key => $profile ) {
				if ( ( 'all' === $demo && 'learndash' !== $key ) || 'default' === $key || $key === $demo ) {
					$plugins = array_merge( $plugins, $profile );
				}
			}

			return $plugins;
		}

		/**
		 * Register the required plugins for this theme.
		 *
		 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
		 */
		public function register_required_plugins() {
			/*
			 * Array of plugin arrays. Required keys are name and slug.
			 * If the source is NOT from the .org repo, then source is also required.
			 */
			$profile = isset( $_GET['demo'] ) ? $_GET['demo'] : '';

			$plugins = $this->get_demo_plugins( $profile );

			$config = array(
				'id'           => 'geeks', // Unique ID for hashing notices for multiple instances of TGMPA.
				'default_path' => '',        // Default absolute path to bundled plugins.
				'menu'         => 'tgmpa-install-plugins', // Menu slug.
				'has_notices'  => true,      // Show admin notices or not.
				'dismissable'  => true,      // If false, a user cannot dismiss the nag message.
				'dismiss_msg'  => '',        // If 'dismissable' is false, this message will be output at top of nag.
				'is_automatic' => false,     // Automatically activate plugins after installation or not.
				'message'      => '',        // Message to output right before the plugins table.
			);

			tgmpa( $plugins, $config );
		}
	}

endif;

return new Geeks_Plugin_Install();
