<?php
/**
 * Geeks Class
 *
 * @since    1.0.0
 * @package  geeks
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Geeks' ) ) :

	/**
	 * The main Geeks class
	 */
	class Geeks {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			$this->includes();
			$this->init_hooks();
		}

		/**
		 * Init hooks.
		 */
		public function init_hooks() {
			add_action( 'after_setup_theme', [ $this, 'setup' ] );
			add_action( 'after_setup_theme', [ $this, 'register_navwalker' ] );
			add_action( 'widgets_init', [ $this, 'widgets_init' ] );
			add_action( 'wp_enqueue_scripts', [ $this, 'scripts' ], 10 );
			add_action( 'wp_enqueue_scripts', [ $this, 'child_scripts' ], 30 ); // After WooCommerce.
			add_action( 'enqueue_block_assets', [ $this, 'block_assets' ] );
			add_filter( 'body_class', [ $this, 'body_classes' ] );
			add_filter( 'wp_page_menu_args', [ $this, 'page_menu_args' ] );
			add_filter( 'navigation_markup_template', [ $this, 'navigation_markup_template' ] );
			add_filter( 'wp_kses_allowed_html', [ $this, 'wp_kses_allowed_html' ], 10, 2 );
			add_filter( 'get_the_archive_title', [ $this, 'archive_title' ] );
			add_action( 'wp_print_styles', [ $this, 'dequeue_css' ], 100 );

		}

		/**
		 * Dequeue files
		 */
		public function dequeue_css() {
			wp_dequeue_style( 'tablepress-default' ); // TablePress
		}

		/**
		 * Include necessary files.
		 */
		public function includes() {
			include_once get_template_directory() . '/inc/templates/abstract-template.php';
			include_once get_template_directory() . '/inc/templates/class-geeks-template-course.php';
		}

		/**
		 * Override archive title
		 *
		 * @param string $title Default archive title.
		 */
		public function archive_title( $title ) {
			if ( is_category() ) {
				$title = single_cat_title( '', false );
			} elseif ( is_tag() ) {
				$title = single_tag_title( '', false );
			} elseif ( is_author() ) {
				$title = '<span class="vcard">' . get_the_author() . '</span>';
			} elseif ( is_tax() ) { // for custom post types.
				$title = single_term_title( '', false );
			} elseif ( is_post_type_archive() ) {
				$title = post_type_archive_title( '', false );
			} elseif ( is_search() ) {
				$title = sprintf( esc_html__( 'Search Results for "%s"', 'geeks' ), get_search_query() );
			}
			return $title;
		}

		/**
		 * Returns an array of allowed HTML tags and attributes for a given context
		 *
		 * @param array[]|string $allowedtags An array of allowed HTML elements and attributes.
		 * @param string         $context The context for which to retrieve tags.
		 */
		public function wp_kses_allowed_html( $allowedtags, $context ) {
			$tags = [];

			switch ( $context ) {
				case 'post-svg':
					$allowedtags = wp_kses_allowed_html( 'post' );
					$tags        = [
						'svg'   => [
							'width'   => true,
							'height'  => true,
							'fill'    => true,
							'viewbox' => true,
							'xmlns'   => true,
						],
						'rect'  => [
							'x'      => true,
							'y'      => true,
							'width'  => true,
							'height' => true,
							'rx'     => true,
							'fill'   => true,
						],
						'g'     => [ 'fill' => true ],
						'title' => [ 'title' => true ],
						'path'  => [
							'd'    => true,
							'fill' => true,
						],
					];
					break;
				case 'post-iframe':
					$allowedtags = wp_kses_allowed_html( 'post' );
					$tags        = [
						'iframe' => [
							'class'           => true,
							'src'             => true,
							'height'          => true,
							'width'           => true,
							'frameborder'     => true,
							'allowfullscreen' => true,
						],
						'div' => [
							'class' => true,
							'video' => true,
							'poster'           => true,
							'source'             => true,
							'class'          => true,
							'type'           => true,
							'src' => true,
							
						],
						'source' => [
							'src' => true,
						]
					];
					break;
			}

			return array_merge( $allowedtags, $tags );
		}

		/**
		 * Register Custom Navigation Walker
		 */
		public function register_navwalker() {
			require get_template_directory() . '/inc/classes/class-wp-bootstrap-navwalker.php';
		}

		/**
		 * Sets up theme defaults and registers support for various WordPress features.
		 *
		 * Note that this function is hooked into the after_setup_theme hook, which
		 * runs before the init hook. The init hook is too late for some features, such
		 * as indicating support for post thumbnails.
		 */
		public function setup() {
			/*
			 * Load Localisation files.
			 *
			 * Note: the first-loaded translation file overrides any following ones if the same translation is present.
			 */

			// Loads wp-content/languages/themes/geeks-it_IT.mo.
			load_theme_textdomain( 'geeks', trailingslashit( WP_LANG_DIR ) . 'themes' );

			// Loads wp-content/themes/child-theme-name/languages/it_IT.mo.
			load_theme_textdomain( 'geeks', get_stylesheet_directory() . '/languages' );

			// Loads wp-content/themes/geeks/languages/it_IT.mo.
			load_theme_textdomain( 'geeks', get_template_directory() . '/languages' );

			/**
			 * Add default posts and comments RSS feed links to head.
			 */
			add_theme_support( 'automatic-feed-links' );

			/**
			 * Remove Block Editor For Widgets
			 */
			remove_theme_support( 'widgets-block-editor' );

			/*
			 * Enable support for Post Thumbnails on posts and pages.
			 *
			 * @link https://developer.wordpress.org/reference/functions/add_theme_support/#Post_Thumbnails
			 */
			add_theme_support( 'post-thumbnails' );

			/**
			 * Enable support for site logo.
			 */
			add_theme_support(
				'custom-logo',
				apply_filters(
					'geeks_custom_logo_args',
					array(
						'height'      => 29,
						'width'       => 112,
						'flex-width'  => true,
						'flex-height' => true,
					)
				)
			);

			/**
			 * Register menu locations.
			 */
			register_nav_menus(
				apply_filters(
					'geeks_register_nav_menus',
					array(
						'navbar'          => esc_html__( 'Navbar Nav Primary', 'geeks' ),
						'social'          => esc_html__( 'Social Media', 'geeks' ),
						'footer'          => esc_html__( 'Nav Footer', 'geeks' ),
						'blog_categories' => esc_html__( 'Blog Categories', 'geeks' ),

					)
				)
			);

			/*
			 * Switch default core markup for search form, comment form, comments, galleries, captions and widgets
			 * to output valid HTML5.
			 */
			add_theme_support(
				'html5',
				apply_filters(
					'geeks_html5_args',
					array(
						'search-form',
						'comment-form',
						'comment-list',
						'gallery',
						'caption',
						'widgets',
						'style',
						'script',
					)
				)
			);

			/**
			 * Setup the WordPress core custom background feature.
			 */
			add_theme_support(
				'custom-background',
				apply_filters(
					'geeks_custom_background_args',
					array(
						'default-color' => apply_filters( 'geeks_default_background_color', 'ffffff' ),
						'default-image' => '',
					)
				)
			);

			/**
			 * Setup the WordPress core custom header feature.
			 */
			add_theme_support(
				'custom-header',
				apply_filters(
					'geeks_custom_header_args',
					array(
						'default-image' => '',
						'header-text'   => false,
						'width'         => 1950,
						'height'        => 500,
						'flex-width'    => true,
						'flex-height'   => true,
					)
				)
			);

			/**
			 *  Add support for the Site Logo plugin and the site logo functionality in JetPack
			 *  https://github.com/automattic/site-logo
			 *  http://jetpack.me/
			 */
			add_theme_support(
				'site-logo',
				apply_filters(
					'geeks_site_logo_args',
					array(
						'size' => 'full',
					)
				)
			);

			/**
			 * Declare support for title theme feature.
			 */
			add_theme_support( 'title-tag' );

			/**
			 * Declare support for selective refreshing of widgets.
			 */
			add_theme_support( 'customize-selective-refresh-widgets' );

			/**
			 * Add support for Block Styles.
			 */
			add_theme_support( 'wp-block-styles' );

			/**
			 * Add support for full and wide align images.
			 */
			add_theme_support( 'align-wide' );

			/**
			 * Add support for editor styles.
			 */
			add_theme_support( 'editor-styles' );

			/**
			 * Add support for editor font size
			 */
			add_theme_support(
				'editor-font-sizes',
				array(
					array(
						'name' => esc_html__( 'Small', 'geeks' ),
						'size' => 14,
						'slug' => 'small',
					),
					array(
						'name' => esc_html__( 'Normal', 'geeks' ),
						'size' => 16,
						'slug' => 'normal',
					),
					array(
						'name' => esc_html__( 'Medium', 'geeks' ),
						'size' => 23,
						'slug' => 'medium',
					),
					array(
						'name' => esc_html__( 'Large', 'geeks' ),
						'size' => 26,
						'slug' => 'large',
					),
					array(
						'name' => esc_html__( 'Huge', 'geeks' ),
						'size' => 37,
						'slug' => 'huge',
					),
				)
			);

			/**
			 * Add support for responsive embedded content.
			 */
			add_theme_support( 'responsive-embeds' );

			/**
			 * Enqueue editor styles.
			 */
			$editor_styles = [
				is_rtl() ? 'assets/css/gutenberg-editor-rtl.css' : 'assets/css/gutenberg-editor.css',
				$this->google_fonts(),

			];

			add_editor_style( $editor_styles );

			/**
			 * Enable excerpt for pages.
			 */
			add_post_type_support( 'page', 'excerpt' );

		}

		/**
		 * Register blog sidebar widget area.
		 *
		 * @return array
		 */
		public function get_blog_sidebar_args() {

			$blog_sidebar_args['blog_sidebar'] = array(
				'name'        => esc_html__( 'Blog Sidebar', 'geeks' ),
				'id'          => 'blog-sidebar',
				'description' => '',
			);

			return apply_filters( 'geeks_blog_sidebar_args', $blog_sidebar_args );
		}

		/**
		 * Register widget area.
		 *
		 * @link https://codex.wordpress.org/Function_Reference/register_sidebar
		 */
		public function widgets_init() {
			$rows    = intval( apply_filters( 'geeks_footer_widget_rows', 1 ) );
			$regions = intval( apply_filters( 'geeks_footer_widget_columns', 4 ) );

			for ( $row = 1; $row <= $rows; $row++ ) {
				for ( $region = 1; $region <= $regions; $region++ ) {
					$footer_n = $region + $regions * ( $row - 1 ); // Defines footer sidebar ID.
					$footer   = sprintf( 'footer_%d', $footer_n );

					if ( 1 === $rows ) {
						/* translators: 1: column number */
						$footer_region_name = sprintf( esc_html__( 'Footer Column %1$d', 'geeks' ), $region );

						/* translators: 1: column number */
						$footer_region_description = sprintf( esc_html__( 'Widgets added here will appear in column %1$d of the footer.', 'geeks' ), $region );
					} else {
						/* translators: 1: row number, 2: column number */
						$footer_region_name = sprintf( esc_html__( 'Footer Row %1$d - Column %2$d', 'geeks' ), $row, $region );

						/* translators: 1: column number, 2: row number */
						$footer_region_description = sprintf( esc_html__( 'Widgets added here will appear in column %1$d of footer row %2$d.', 'geeks' ), $region, $row );
					}

					$sidebar_args[ $footer ] = array(
						'name'        => $footer_region_name,
						'id'          => sprintf( 'footer-%d', $footer_n ),
						'description' => $footer_region_description,
					);
				}
			}

			$sidebar_args = apply_filters( 'geeks_sidebar_args', $sidebar_args );

			foreach ( $sidebar_args as $sidebar => $args ) {
				$widget_tags = array(
					'before_widget' => '<div id="%1$s" class="widget mb-4 mb-0-last-child %2$s">',
					'after_widget'  => '</div>',
					'before_title'  => '<h3 class="widget-title fw-bold mb-3">',
					'after_title'   => '</h3>',
				);

				/**
				 * Dynamically generated filter hooks. Allow changing widget wrapper and title tags. See the list below.
				 *
				 * 'geeks_header_widget_tags'
				 * 'geeks_sidebar_widget_tags'
				 *
				 * 'geeks_footer_1_widget_tags'
				 * 'geeks_footer_2_widget_tags'
				 * 'geeks_footer_3_widget_tags'
				 * 'geeks_footer_4_widget_tags'
				 */
				$filter_hook = sprintf( 'geeks_%s_widget_tags', $sidebar );
				$widget_tags = apply_filters( $filter_hook, $widget_tags );

				if ( is_array( $widget_tags ) ) {
					register_sidebar( $args + $widget_tags );
				}
			}

			$blog_sidebar_args = $this->get_blog_sidebar_args();

			foreach ( $blog_sidebar_args  as $sidebar => $args ) {
				$widget_tags = array(
					'before_widget' => '<div id="%1$s" class="card mb-4 border widget %2$s"><div class="card-body p-4">',
					'after_widget'  => '</div></div>',
					'before_title'  => '<h3 class="widget_title mb-3">',
					'after_title'   => '</h3>',
				);

				/**
				 * Dynamically generated filter hooks. Allow changing widget wrapper and title tags. See the list below.
				 *
				 * 'geeks_shop_sidebar_widget_tags'
				 */
				$filter_hook = sprintf( 'geeks_%s_widget_tags', $sidebar );
				$widget_tags = apply_filters( $filter_hook, $widget_tags );

				if ( is_array( $widget_tags ) && geeks_post_loop_sidebar_enabled() ) {
					register_sidebar( $args + $widget_tags );
				}
			}

		}

		/**
		 * Enqueue scripts and styles.
		 *
		 * @since  1.0.0
		 */
		public function scripts() {
			global $geeks_version;

			/**
			 * Styles
			 */
			$css_assets = [
				'fontawesome'      => '/assets/libs/fontawesome/css/all.min.css',
				'feather'          => '/assets/fonts/feather/feather.css',
				'dragula'          => '/assets/libs/dragula/dist/dragula.min.css',
				'mdi'              => '/assets/libs/@mdi/font/css/materialdesignicons.min.css',
				'prism'            => '/assets/libs/prismjs/themes/prism.css',
				'dropzone'         => '/assets/libs/dropzone/dist/dropzone.css',
				'magnific-popup'   => '/assets/libs/magnific-popup/dist/magnific-popup.css',
				'bootstrap-select' => '/assets/libs/bootstrap-select/dist/css/bootstrap-select.min.css',
				'tagify'           => '/assets/libs/@yaireo/tagify/dist/tagify.css',
				'tiny-slider'      => '/assets/libs/tiny-slider/dist/tiny-slider.css',
				'tippy'            => '/assets/libs/tippy.js/dist/tippy.css',
				'flatpickr'        => '/assets/libs/flatpickr/dist/flatpickr.min.css',

			];

			foreach ( $css_assets as $handle => $css_asset ) {
				wp_enqueue_style( $handle, get_template_directory_uri() . $css_asset, '', $geeks_version );
			}

			if( is_rtl() ) {
				wp_enqueue_style( 'owl-carousel-default-css', get_template_directory_uri() . '/assets/libs/owl-carousel/dist/assets/owl.theme.default.min.css', '', $geeks_version );
				wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/assets/libs/owl-carousel/dist/assets/owl.carousel.min.css', '', $geeks_version );
			}

			wp_enqueue_style( 'geeks-style', get_template_directory_uri() . '/style.min.css', '', $geeks_version );
			wp_style_add_data( 'geeks-style', 'rtl', 'replace' );

			if ( apply_filters( 'geeks_use_predefined_colors', true ) && filter_var( get_theme_mod( 'geeks_enable_custom_color', 'no' ), FILTER_VALIDATE_BOOLEAN ) ) {
				wp_enqueue_style( 'geeks-color', get_template_directory_uri() . '/assets/css/colors/' . 'color.css', '', $geeks_version );
			}


			/**
			 * Fonts
			 */
			wp_enqueue_style( 'geeks-fonts', $this->google_fonts(), array(), $geeks_version );

			/**
			 * Scripts
			 */
			if( is_rtl()) {
				wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/libs/owl-carousel/dist/owl.carousel.min.js', array( 'jquery' ), $geeks_version, true );
			}

			$js_assets = [
				'bootstrap-bundle'      => '/assets/libs/bootstrap/dist/js/bootstrap.bundle.min.js',
				'odometer'              => '/assets/libs/odometer/odometer.min.js',
				'jquery-slimscroll'     => '/assets/libs/jquery-slimscroll/jquery.slimscroll.min.js',
				'jquery-magnific-popup' => '/assets/libs/magnific-popup/dist/jquery.magnific-popup.min.js',
				'bootstrap-select'      => '/assets/libs/bootstrap-select/dist/js/bootstrap-select.min.js',
				'flatpickr'             => '/assets/libs/flatpickr/dist/flatpickr.min.js',
				'jquery-inputmask'      => '/assets/libs/inputmask/dist/jquery.inputmask.min.js',
				'apexcharts'            => '/assets/libs/apexcharts/dist/apexcharts.min.js',
				'quill'                 => '/assets/libs/quill/dist/quill.min.js',
				'file-upload-preview'   => '/assets/libs/file-upload-with-preview/dist/file-upload-with-preview.min.js',
				'dragula'               => '/assets/libs/dragula/dist/dragula.min.js',
				'bs-stepper'            => '/assets/libs/bs-stepper/dist/js/bs-stepper.min.js',
				'dropzone'              => '/assets/libs/dropzone/dist/min/dropzone.min.js',
				'jQuery-print'          => '/assets/libs/jQuery.print/jQuery.print.js',
				'prism'                 => '/assets/libs/prismjs/prism.js',
				'prism-scss'            => '/assets/libs/prismjs/components/prism-scss.min.js',
				'tagify'                => '/assets/libs/@yaireo/tagify/dist/tagify.min.js',
				'tiny-slider'           => '/assets/libs/tiny-slider/dist/min/tiny-slider.js',
				'popper'                => '/assets/libs/@popperjs/core/dist/umd/popper.min.js',
				'tippy-bundle'          => '/assets/libs/tippy.js/dist/tippy-bundle.umd.min.js',
				'typed'                 => '/assets/libs/typed.js/lib/typed.min.js',
				'clipboard-js'          => '/assets/libs/clipboard.js/clipboard.min.js',
				'theme'                 => '/assets/js/theme.min.js',
				'geeks-scripts'         => '/assets/js/geeks.js',
				'masonry'               => '/assets/libs/masonry/masonry.pkgd.min.js',

			];

			foreach ( $js_assets as $handle => $js_asset ) {
				wp_enqueue_script( $handle, get_template_directory_uri() . $js_asset, array( 'jquery' ), $geeks_version, true );
			}

			if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
				wp_enqueue_script( 'comment-reply' );
			}

			$admin_ajax_url = admin_url( 'admin-ajax.php' );

			$current_lang = apply_filters( 'wpml_current_language', null );
			if ( $current_lang ) {
				$admin_ajax_url = add_query_arg( 'lang', $current_lang, $admin_ajax_url );
			}

			$geeks_options = apply_filters(
				'around_localize_script_data',
				array(
					'ajax_url'        => $admin_ajax_url,
					'ajax_loader_url' => get_template_directory_uri() . '/assets/images/ajax-loader.gif',

				)
			);

			wp_localize_script( 'geeks-scripts', 'geeks_options', $geeks_options );
		}

		/**
		 * Enqueue block assets.
		 *
		 * @since 2.5.0
		 */
		public function block_assets() {
			global $geeks_version;

			// Styles.
			wp_enqueue_style( 'geeks-gutenberg-blocks', get_template_directory_uri() . '/assets/css/gutenberg-blocks.css', '', $geeks_version );
			wp_style_add_data( 'geeks-gutenberg-blocks', 'rtl', 'replace' );
		}


		/**
		 * Register Google fonts.
		 *
		 * @since 1.0.0
		 * @return string Google fonts URL for the theme.
		 */
		public function google_fonts() {

			$fonts_url = 'https://fonts.googleapis.com/css2?family=Inter:wght@100;200;300;400;500;600;700;800;900&display=swap';

			return $fonts_url;
		}

		/**
		 * Enqueue child theme stylesheet.
		 * A separate function is required as the child theme css needs to be enqueued _after_ the parent theme
		 * primary css and the separate WooCommerce css.
		 *
		 * @since  1.5.3
		 */
		public function child_scripts() {
			if ( is_child_theme() ) {
				$child_theme = wp_get_theme( get_stylesheet() );
				wp_enqueue_style( 'geeks-child-style', get_stylesheet_uri(), array(), $child_theme->get( 'Version' ) );
			}
		}

		/**
		 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
		 *
		 * @param array $args Configuration arguments.
		 * @return array
		 */
		public function page_menu_args( $args ) {
			$args['show_home'] = true;
			return $args;
		}

		/**
		 * Adds custom classes to the array of body classes.
		 *
		 * @param array $classes Classes for the body element.
		 * @return array
		 */
		public function body_classes( $classes ) {
			// Adds a class to blogs with more than 1 published author.
			if ( is_multi_author() ) {
				$classes[] = 'group-blog';
			}

			/**
			 * Adds a class when WooCommerce is not active.
			 *
			 * @todo Refactor child themes to remove dependency on this class.
			 */
			$classes[] = 'no-wc-breadcrumb';

			/**
			 * What is this?!
			 * Take the blue pill, close this file and forget you saw the following code.
			 * Or take the red pill, filter geeks_make_me_cute and see how deep the rabbit hole goes...
			 */
			$cute = apply_filters( 'geeks_make_me_cute', false );

			if ( true === $cute ) {
				$classes[] = 'geeks-cute';
			}

			// If our main sidebar doesn't contain widgets, adjust the layout to be full-width.
			if ( ! is_active_sidebar( 'blog-sidebar' ) ) {
				$classes[] = 'geeks-full-width-content';
			}

			// Add class when using homepage template + featured image.
			if ( is_page_template( 'template-homepage.php' ) && has_post_thumbnail() ) {
				$classes[] = 'has-post-thumbnail';
			}

			// Add class when Secondary Navigation is in use.
			if ( has_nav_menu( 'secondary' ) ) {
				$classes[] = 'geeks-secondary-navigation';
			}

			// Add class if align-wide is supported.
			if ( current_theme_supports( 'align-wide' ) ) {
				$classes[] = 'geeks-align-wide';
			}

			if ( is_page() || is_post_type_archive( 'post' ) || is_singular( 'post' ) || is_home() || is_404() || is_search() || ( 'post' == get_post_type() && ( is_category() || is_tag() || is_author() || is_date() || is_year() || is_month() || is_time() ) ) ) {
				$classes[] = 'bg-white';
			}

			if ( function_exists( 'geeks_option_enabled_post_types' ) && is_singular( geeks_option_enabled_post_types() ) ) {
				$clean_meta_data = get_post_meta( get_the_ID(), '_gk_page_options', true );
				$gk_page_options = maybe_unserialize( $clean_meta_data );

				if ( isset( $gk_page_options['general'] ) && isset( $gk_page_options['general']['body_classes'] ) && ! empty( $gk_page_options['general']['body_classes'] ) ) {
					$classes[] = $gk_page_options['general']['body_classes'];

					if ( in_array( 'bg-light', $classes ) ) {
						$classes = geeks_remove_bg_class( 'bg-white', $classes );
					}      
				}
			}

			return $classes;
		}

		/**
		 * Custom navigation markup template hooked into `navigation_markup_template` filter hook.
		 */
		public function navigation_markup_template() {
			$template  = '<nav id="post-navigation" class="navigation %1$s" role="navigation" aria-label="' . esc_html__( 'Post Navigation', 'geeks' ) . '">';
			$template .= '<h2 class="screen-reader-text">%2$s</h2>';
			$template .= '<div class="nav-links">%3$s</div>';
			$template .= '</nav>';

			return apply_filters( 'geeks_navigation_markup_template', $template );
		}

		/**
		 * Add styles for embeds
		 */
		public function print_embed_styles() {
			global $geeks_version;

			wp_enqueue_style( 'source-sans-pro', '//fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,300italic,400italic,700,900', array(), $geeks_version );
			$accent_color     = get_theme_mod( 'geeks_accent_color' );
			$background_color = geeks_get_content_background_color();
			?>
			<style type="text/css">
				.wp-embed {
					padding: 2.618em !important;
					border: 0 !important;
					border-radius: 3px !important;
					font-family: "Source Sans Pro", "Open Sans", sans-serif !important;
					background-color: <?php echo esc_html( geeks_adjust_color_brightness( $background_color, -7 ) ); ?> !important;
				}

				.wp-embed .wp-embed-featured-image {
					margin-bottom: 2.618em;
				}

				.wp-embed .wp-embed-featured-image img,
				.wp-embed .wp-embed-featured-image.square {
					min-width: 100%;
					margin-bottom: .618em;
				}

				a.wc-embed-button {
					padding: .857em 1.387em !important;
					font-weight: 600;
					background-color: <?php echo esc_attr( $accent_color ); ?>;
					color: #fff !important;
					border: 0 !important;
					line-height: 1;
					border-radius: 0 !important;
					box-shadow:
						inset 0 -1px 0 rgba(#000,.3);
				}

				a.wc-embed-button + a.wc-embed-button {
					background-color: #60646c;
				}
			</style>
			<?php
		}
	}
endif;

return new Geeks();
