<?php
/**
 * Geeks LearnPress Class
 *
 * @package  geeks
 * @since    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Geeks_LearnPress' ) ) :

	/**
	 * The Geeks LearnPress Integration class
	 */
	class Geeks_LearnPress {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ), 10 );
			add_filter( 'learn-press/frontend-default-styles', [ $this, 'set_default_styles' ], 10 );
			add_filter( 'learn-press/override-templates', '__return_true', 10 );
			add_filter( 'learn_press_course_loop_begin', [ $this, 'course_loop_begin' ], 10 );
			add_filter( 'learn-press/course-tabs', [ $this, 'course_tabs' ], 90 );
			add_action( 'init', [ $this, 'adjust_hooks' ], 20 );
			add_action( 'init', [ $this, 'dequeue_css'], PHP_INT_MAX );
			add_filter( 'geeks_disable_page_header', [ $this, 'page_header' ], 10 );
			add_filter( 'geeks_navbar_disabled', [ $this, 'page_navbar' ], 10 );
			add_filter( 'geeks_footer_disabled', [ $this, 'page_footer' ], 10 );
			add_filter( 'body_class', [ $this, 'body_classes' ] );

		}

		/**
		 * Disable page header on certain conditions
		 */
		public function page_header( $disabled ) {
			global $wp;

			// Disable on profile pages.
			if ( learn_press_is_profile() ) {
				$disabled = true;
			}

			// Disable on order received page.
			if ( isset( $wp->query_vars['lp-order-received'] ) ) {
				$disabled = true;
			}

			return $disabled;
		}

		/**
		 * Disable page navbar
		 */
		public function page_navbar( $disabled ) {
			global $wp;
			
			// Disable if login or register form is displayed.
			if ( geeks_profile_is_login_register() || geeks_is_lesson() ) {
				$disabled = true;
			}

			// Disable on order received page.
			if ( isset( $wp->query_vars['lp-order-received'] ) ) {
				$disabled = true;
			}

			return $disabled;
		}

		/**
		 * Disable page footer
		 */
		public function page_footer( $disabled ) {
			global $wp;

			// Disable if login or register form is displayed.
			if ( geeks_profile_is_login_register() ) {
				$disabled = true;
			}

			// Disable on order received page.
			if ( isset( $wp->query_vars['lp-order-received'] ) ) {
				$disabled = true;
			}

			if( geeks_is_lesson()) {
				$disabled = true;
			}

			return $disabled;
		}

		/**
		 * Enqueue scripts related to LearnPress
		 */
		public function scripts() {
			global $geeks_version;
			
			wp_enqueue_script( 'geeks-learnpress', get_template_directory_uri() . '/assets/js/geeks-learnpress.js', array( 'jquery' ), $geeks_version, true );
		}

		/**
		 * Override loop begin
		 *
		 * @param string $html Loop Start HTML.
		 */
		public function course_loop_begin( $html ) {
			$html = '<ul class="learn-press-courses list-courses list-unstyled row row-cols-lg-3 row-cols-md-2" data-layout="' . learn_press_get_courses_layout() . '">';
			return $html;
		}

		/**
		 * Override Course Tabs
		 * 
		 * @param array $defaults All available tabs
		 */
		public function course_tabs( $tabs ) {
			$course = LP_Course::get_course( get_the_ID() );

			if ( isset( $tabs['overview'] ) ) {
				$tabs['overview']['content_title'] = esc_html__( 'Course Overview', 'geeks' );
			}

			if ( isset( $tabs['faqs'] ) ) {
				$tabs['faqs']['content_title'] = esc_html__( 'Frequently Asked Questions', 'geeks' );
			}

			if ( isset( $tabs['reviews'] ) ) {
				$tabs['reviews']['content_title'] = esc_html__( 'How students rated this course', 'geeks' );
			}

			if ( ! empty ( $course->get_extra_info( 'requirements' ) || $course->get_extra_info( 'key_features' ) ||  $course->get_extra_info( 'target_audiences' ) ) ) {
				$tabs['info'] = [
					'title'    => esc_html__( 'Additional Info', 'geeks' ),
					'priority' => 20,
					'callback' => LP()->template( 'course' )->func( 'course_extra_boxes' )
				];
			}
			

			unset( $tabs['instructor'] );

			return $tabs;
		}

		/**
		 * Adjust hooks in LearnPress addons
		 */
		public function adjust_hooks() {

		}

		/**
		 * Dequeue CSS not used by the theme
		 */
		public function dequeue_css() {
			wp_dequeue_style( 'lp-course-wishlist-style' );
		}
		/**
		 * Unset default styles in frontend.
		 *
		 * @return array
		 */
		public function set_default_styles( $styles ) {
			unset( $styles['lp-font-awesome-5'] );
			unset( $styles['lp-bundle'] );
			unset( $styles['learnpress'] );
			unset( $styles['learnpress-widgets'] );

			return $styles;
		}

		/**
		 * Adds custom classes to the array of body classes.
		 *
		 * @param array $classes Classes for the body element.
		 * @return array
		 */
		public function body_classes( $classes ) {

			if ( learn_press_is_checkout() || learn_press_is_profile() ) {
				if ( ( $key = array_search('bg-white', $classes) ) !== false ) {
	    			unset( $classes[$key] );
				}
			}

			return $classes;
		}

	}

endif;

return new Geeks_LearnPress();
