<?php
/**
 * Functions used related to Instructor
 */

/**
 * Get Instructor
 */
function geeks_get_instructor( $user_id, $field = '' ) {
    $user = learn_press_get_user( $user_id );
    return $field ? $user->get_data( $field ) : $user;
}

/**
 * Get Instructor avatar
 */
function geeks_get_instructor_avatar( $user, $size = 96, $class = 'rounded-circle' ) {
	if ( is_numeric( $user ) ) {
        $instructor = geeks_get_instructor( $user );
    } else {
        $instructor = $user;
    }

    return geeks_get_profile_pic( $instructor, $size, array( 'class' => $class ) );
}

/**
 * Get Instructor profile link URL
 */
function geeks_instructor_profile_link( $course ) {
    return learn_press_user_profile_link( get_post_field( 'post_author', $course->get_id() ) );
}

/**
 * Get Stats for the instructor
 */
function geeks_get_instructor_stats( $user_id, $view = 'single' ) {
	
	$user_id        = absint( $user_id );
	$stats_students = get_user_meta( $user_id, '_geeks_instructor_stats_students', true );
	$stats_reviews  = get_user_meta( $user_id, '_geeks_instructor_stats_reviews', true );
	$stats_rating   = get_user_meta( $user_id, '_geeks_instructor_stats_rating', true );
	$stats_courses  = count_user_posts( $user_id, LP_COURSE_CPT );

	if ( ! $stats_students || ! $stats_courses || ! $stats_reviews || ! $stats_rating ) {

		$transient_name = 'geeks_instructor_stats_' . $user_id;
		$query_args     = [
			'author'      => $user_id,
			'post_type'   => LP_COURSE_CPT,
			'post_status' => 'publish'
		];

		$query_args_str = http_build_query( $query_args );
		$transient      = get_transient( $transient_name );
		$courses        = $transient && isset( $transient[ $query_args_str ] ) ? $transient[ $query_args_str ] : false;

		if ( false === $transient ) {
			$courses = new WP_Query( $query_args );

			if ( $transient ) {
				$transient[ $query_args_str ] = $courses;
			} else {
				$transient = [ $query_args_str => $courses ];
			}

			set_transient( $transient_name, $transient, DAY_IN_SECONDS );
		}

		$stats_students = 0; 
	 	$stats_reviews  = 0;
	 	$stats_rating   = 0.0;

		if ( $courses->have_posts() ) {
			while ( $courses->have_posts() ) {
				$courses->the_post();
				
				$course         = learn_press_get_course( get_the_ID() );
				$stats_students = $stats_students + absint( $course->get_users_enrolled() );
				$rating_info    = geeks_get_course_rating_info();

				if ( $rating_info ) {
					$stats_reviews = $stats_reviews + absint( $rating_info['rating'] );
					$stats_rating  = $stats_rating + floatval( $rating_info['count'] );
				}
			}

			wp_reset_postdata();
		}

		update_user_meta( $user_id, '_geeks_instructor_stats_students', $stats_students );
		update_user_meta( $user_id, '_geeks_instructor_stats_reviews', $stats_reviews );
		update_user_meta( $user_id, '_geeks_instructor_stats_rating', $stats_rating );
	}

	if ( 'grid' === $view ) {
		$stats = [ 
			'students' => [
				'label' => esc_html__( 'Students', 'geeks' ),
				'value' => $stats_students, 
			],
			'reviews'  => [
				'label' => esc_html__( 'Reviews', 'geeks' ),
				'value' => $stats_reviews, 
			],
			'rating'   => [
				'label' => esc_html__( 'Instructor Rating', 'geeks' ),
				'value' => $stats_rating 
			],
			'courses'  => [
				'label' => esc_html__( 'Courses', 'geeks' ),
				'value' => $stats_courses, 
			],
		];
	} else {
		$stats = [ 
			'courses'  => [
				'label' => esc_html__( 'Courses', 'geeks' ),
				'value' => $stats_courses, 
			],
			'students' => [
				'label' => esc_html__( 'Students', 'geeks' ),
				'value' => $stats_students, 
			],
			'reviews'  => [
				'label' => esc_html__( 'Reviews', 'geeks' ),
				'value' => $stats_reviews, 
			],
			'rating'   => [
				'label' => esc_html__( 'Instructor Rating', 'geeks' ),
				'value' => $stats_rating 
			],
		];
	}

	return apply_filters( 'geeks_instructor_stats', $stats, $user_id );
}

/**
 * General function to get instructors
 */
function geeks_get_instructors( $args = array() ) {
	$defaults = [
		'number'              => 4,
		'has_published_posts' => array( LP_COURSE_CPT ),
	];
	$args = wp_parse_args( $args, $defaults );
	return new WP_User_Query( $args );
}

/**
 * Get Instructors by most published courses
 */
function geeks_get_instructors_by_courses( $args = array() ) {
	$args['orderby'] = 'post_count';
	$args['order']   = 'DESC';
	return geeks_get_instructors( $args );
}

/**
 * Get Instructors by popularity
 */
function geeks_get_instructors_by_popularity( $args = array() ) {
	$args['orderby']  = 'meta_value_num';
	$args['order']    = 'DESC';
	$args['meta_key'] = '_geeks_instructor_stats_students';
	return geeks_get_instructors( $args );
}

/**
 * Get Instructors by rating
 */
function geeks_get_instructors_by_rating( $args = array() ) {
	$args['orderby']  = 'meta_value_num';
	$args['order']    = 'DESC';
	$args['meta_key'] = '_geeks_instructor_stats_rating';
	return geeks_get_instructors( $args );
}

/**
 * Get Instructors by term
 */
function geeks_get_instructors_by_term_id( $term_id = 0, $view = 'select' ) {
	global $wpdb;

	if ( 0 === $term_id ) {
		$term_id = geeks_get_course_cat_id();
	}

	$sql         = "SELECT DISTINCT {$wpdb->posts}.post_author FROM {$wpdb->term_relationships} INNER JOIN {$wpdb->term_taxonomy} INNER JOIN {$wpdb->posts} WHERE {$wpdb->term_taxonomy}.term_taxonomy_id = {$wpdb->term_relationships}.term_taxonomy_id AND {$wpdb->term_taxonomy}.term_id = %s AND {$wpdb->posts}.ID = {$wpdb->term_relationships}.object_id AND {$wpdb->posts}.post_type = %s";
	$query       = $wpdb->prepare( $sql, $term_id, LP_COURSE_CPT );
	$user_ids    = $wpdb->get_col( $query );
	$instructors = false;
	$args        = [ 'include' => $user_ids ];
	
	if ( ! empty ( $user_ids ) ) {
		switch( $view ) {
			case 'popular' :
			$instructors = geeks_get_instructors_by_popularity( $args );
			break;
			case 'rated' :
			$instructors = geeks_get_instructors_by_rating( $args );
			break;
			case 'active' :
			$instructors = geeks_get_instructors_by_courses( $args );
			break;
			case 'select':
			$instructors = geeks_get_selected_instructors( $user_ids );
			break;
		}
	}

	return $instructors;
}

/**
 * Get selected instructors
 */
function geeks_get_selected_instructors( $user_ids ) {
	$instructors = false;
	if ( ! empty( $user_ids ) ) {
		$instructors = geeks_get_instructors( array( 'include' => $user_ids ) );
	}

	return $instructors;
}