<?php
/**
 * Template functions used globally in Geeks Theme
 */

if ( ! function_exists( 'geeks_display_page_header' ) ) {
	/**
	 * Display the page header
	 *
	 * @param string $title Title of the page.
	 * @param string $lead  Lead of the page.
	 */
	function geeks_display_page_header( $title, $lead = '' ) {
		geeks_get_template( 'global/page-header.php', array( 'title' => $title, 'lead' => $lead ) );
	}
}

if ( ! function_exists( 'geeks_the_post_time_string') ) {
	/**
	 * Get the post time string
	 *
	 * @param array $args Arguments for time string.
	 * @return string
	 */
	function geeks_the_post_time_string( $args = array() ) {
		$defaults = array(
			'link_css' => 'text-body stretched-link',
			'link'     => get_permalink(),
		);

		$args = wp_parse_args( $args, $defaults );

		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published d-none" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		echo wp_kses(
			sprintf( '<a href="%1$s" class="%2$s" rel="bookmark">%3$s</a>', esc_url( $args['link'] ), esc_attr( $args['link_css'] ), $time_string ),
			array(
				'span' => array(
					'class' => array(),
				),
				'a'    => array(
					'class' => array(),
					'href'  => array(),
					'title' => array(),
					'rel'   => array(),
				),
				'time' => array(
					'datetime' => array(),
					'class'    => array(),
				),
			)
		);
	}
}

if ( ! function_exists( 'geeks_form_errors' ) ) {
	/**
	 * Used for tracking error messages.
	 */
	function geeks_form_errors() {
		static $wp_error; // Will hold global variable safely.
		$wp_error = isset( $wp_error ) ? $wp_error : new WP_Error( null, null, null );
		return $wp_error;
	}
}

if ( ! function_exists( 'geeks_show_error_messages' ) ) {
	/**
	 * Display error messages.
	 */
	function geeks_show_error_messages() {
		$codes = geeks_form_errors()->get_error_codes();
		if ( $codes ) {
			echo '<div class="notification alert alert-danger">';
				// Loop error codes and display errors.
			foreach ( $codes as $code ) {
				$message = geeks_form_errors()->get_error_message( $code );
				echo '<span>' . esc_html( $message ) . '</span><br/>';
			}
			echo '</div>';
		}
	}
}

if ( ! function_exists( 'geeks_form_success' ) ) {
	/**
	 * Form success or not.
	 */
	function geeks_form_success() {
		static $wp_error; // Will hold global variable safely.
		$wp_error = isset( $wp_error ) ? $wp_error : new WP_Error( null, null, null );
		return $wp_error;
	}
}

if ( ! function_exists( 'geeks_show_success_messages' ) ) {
	/**
	 * Display success messages.
	 */
	function geeks_show_success_messages() {
		$codes = geeks_form_success()->get_error_codes();
		if ( $codes ) {
			echo '<div class="notification alert alert-success">';
				// Loop success codes and display success.
			foreach ( $codes as $code ) {
				$message = geeks_form_success()->get_error_message( $code );
				echo '<span>' . esc_html( $message ) . '</span><br/>';
			}
			echo '</div>';
		}
	}
}

if ( ! function_exists( 'geeks_add_new_member' ) ) {
	/**
	 * Register a new user. Used in elementor forms Widget.
	 */
	function geeks_add_new_member() {
		$nonce_value = geeks_get_var( $_REQUEST['geeks_register_nonce'], geeks_get_var( $_REQUEST['_wpnonce'], '' ) ); // @codingStandardsIgnoreLine.

		if ( isset( $_POST['geeks_register_check'] ) && wp_verify_nonce( $nonce_value, 'geeks-register-nonce' ) ) {
			$register_user_name_enabled = apply_filters( 'geeks_register_user_name_enabled', true );
			$default_role = 'subscriber';

			if ( geeks_is_tutor_activated() ) {
				$default_role = 'customer';
			}

			$available_roles = array( 'subscriber', 'customer' );

			if ( isset( $_POST['email'] ) ) {
				$user_email = wp_unslash( $_POST['email'] ); // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
			}

			$user_role = ! empty( $_POST['geeks_user_role'] ) && in_array( $_POST['geeks_user_role'], $available_roles, true ) ? sanitize_text_field( wp_unslash( $_POST['geeks_user_role'] ) ) : $default_role;

			if ( ! empty( $_POST['username'] ) ) {
				$user_login = wp_unslash( $_POST['username'] ); // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
			} else {
				$user_login = sanitize_user( current( explode( '@', $user_email ) ), true );

				// Ensure username is unique.
				$append       = 1;
				$o_user_login = $user_login;

				while ( username_exists( $user_login ) ) {
					$user_login = $o_user_login . $append;
					$append++;
				}
			}

			if ( username_exists( $user_login ) && $register_user_name_enabled ) {
				// Username already registered.
				geeks_form_errors()->add( 'username_unavailable', esc_html__( 'Username already taken', 'geeks' ) );
			}

			if ( ! validate_username( $user_login ) && $register_user_name_enabled ) {
				// Invalid username.
				geeks_form_errors()->add( 'username_invalid', esc_html__( 'Invalid username', 'geeks' ) );
			}

			if ( '' === $user_login && $register_user_name_enabled ) {
				// Empty username.
				geeks_form_errors()->add( 'username_empty', esc_html__( 'Please enter a username', 'geeks' ) );
			}

			if ( ! is_email( $user_email ) ) {
				// Invalid email.
				geeks_form_errors()->add( 'email_invalid', esc_html__( 'Invalid email', 'geeks' ) );
			}

			if ( email_exists( $user_email ) ) {
				// Email address already registered.
				geeks_form_errors()->add( 'email_used', esc_html__( 'Email already registered', 'geeks' ) );
			}

			$password           = wp_generate_password();
			$password_generated = true;

			if ( apply_filters( 'geeks_register_password_enabled', true ) && isset( $_POST['password'] ) && ! empty( $_POST['password'] ) ) {
				$password           = $_POST['password']; // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized, WordPress.Security.ValidatedSanitizedInput.MissingUnslash
				$password_generated = false;

				if ( isset( $_POST['confirmPassword'] ) && ! empty( $_POST['confirmPassword'] ) ) {
					if ( $_POST['password'] !== $_POST['confirmPassword'] ) {
						// Mismatched Password.
						geeks_form_errors()->add( 'wrong_password', esc_html__( 'Password you entered is mismatched', 'geeks' ) );
					}
				}
			}

			do_action( 'geeks_wp_register_form_custom_field_validation' );

			$errors = geeks_form_errors()->get_error_messages();

			// Only create the user in if there are no errors.
			if ( empty( $errors ) ) {

				$new_user_data = array(
					'user_login' => $user_login,
					'user_pass'  => $password,
					'user_email' => $user_email,
					'role'       => $user_role,
				);

				$new_user_id = wp_insert_user( $new_user_data );

				if ( $new_user_id ) {
					// Send an email to the admin alerting them of the registration.
					if ( apply_filters( 'geeks_new_user_notification', false ) ) {
						wc()->mailer()->customer_new_account( $new_user_id, $new_user_data, $password_generated );
					} else {
						wp_new_user_notification( $new_user_id, null, 'both' );
					}

					// Log the new user in.
					$creds                  = array();
					$creds['user_login']    = $user_login;
					$creds['user_password'] = $password;
					$creds['remember']      = true;
					if ( $password_generated ) {
						geeks_form_success()->add( 'verify_user', esc_html__( 'Account created successfully. Please check your email to create your account password', 'geeks' ) );
					} else {
						$user = wp_signon( $creds, false );
						// Send the newly created user to the home page after logging them in.
						if ( is_wp_error( $user ) ) {
							echo wp_kses_post( $user->get_error_message() );
						} else {
							$wp_user      = get_user_by( 'login', $creds['user_login'] );
							$wp_user_arr  = get_object_vars( $wp_user );
							$wp_user_role = $wp_user_arr['roles'][0];

							if ( get_option( 'woocommerce_myaccount_page_id' ) ) {
								$account_url = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) );
							} else {
								$account_url = home_url( '/' );
							}

							switch ( $wp_user_role ) {
								case 'subscriber':
									$redirect_url = $account_url;
									break;

								default:
									$redirect_url = home_url( '/' );
									break;
							}

							wp_safe_redirect( apply_filters( 'geeks_redirect_register_url', $redirect_url, $user ) );
						}
						exit;
					}
				}
			}
		}
	}
}

add_action( 'wp_loaded', 'geeks_add_new_member' );
